==> protector-3.1.zip: xoops_trust_path/modules/protector/language/japanese/modinfo.php <==
<?php

if( defined( 'FOR_XOOPS_LANG_CHECKER' ) ) $mydirname = 'protector' ;
$constpref = '_MI_' . strtoupper( $mydirname ) ;

if( defined( 'FOR_XOOPS_LANG_CHECKER' ) || ! defined( $constpref.'_LOADED' ) ) {

define( $constpref.'_LOADED' , 1 ) ;

// The name of this module
define($constpref."_NAME","Xoops Protector");

// A brief description of this module
define($constpref."_DESC","դ빶⤫XOOPS뤿Υ⥸塼<br />DoS,SQL Injection,ѿȤäɤޤ");

// Menu
define($constpref."_ADMININDEX","Protect Center");
define($constpref."_ADVISORY","ƥ");
define($constpref."_PREFIXMANAGER","PREFIX ޥ͡");
define($constpref.'_ADMENU_MYBLOCKSADMIN','') ;

// Configs
define($constpref.'_GLOBAL_DISBL','ưΰŪ');
define($constpref.'_GLOBAL_DISBLDSC','ɸưŪ̵ޤ<br />꤬褵줿̵뤳Ȥ˺ʤ');

define($constpref.'_RELIABLE_IPS','ѤǤIP');
define($constpref.'_RELIABLE_IPSDSC','DoSι⸡ΤԤʤIPɥ쥹| ǶڤäƵҤޤ^Ƭ$ɽޤ');

define($constpref.'_LOG_LEVEL','٥');
define($constpref.'_LOG_LEVELDSC','');

define($constpref.'_BANIP_TIME0','IPݤδ()');

define($constpref.'_LOGLEVEL0','ϰڤʤ');
define($constpref.'_LOGLEVEL15','ι⤤Τ');
define($constpref.'_LOGLEVEL63','㤤Τϥʤ');
define($constpref.'_LOGLEVEL255','Υ󥰤ͭȤ');

define($constpref.'_HIJACK_TOPBIT','å³ݸӥå');
define($constpref.'_HIJACK_TOPBITDSC','åϥåк<br />̾32(bit)ǡӥåȤݸޤ<br />ProxyѤʤɤǡIPɥ쥹ѤˤϡưʤĹΥӥåȿꤷޤ<br />㤨С192.168.0.0192.168.0.255ưǽ硢ˤ24(bit)Ȼꤷޤ');
define($constpref.'_HIJACK_DENYGP','IPưػߤ륰롼');
define($constpref.'_HIJACK_DENYGPDSC','åϥåк<br />å˰ۤʤIPɥ쥹ϰϡʾˤƥӥåȿˤΥػߤ륰롼פꤷޤ<br />ʴԤˤĤONˤ뤳Ȥ򤪴ᤷޤ');
define($constpref.'_SAN_NULLBYTE','̥ʸ򥹥ڡѹ');
define($constpref.'_SAN_NULLBYTEDSC','ʸλ饯Ǥ "\\0" ϡդ빶Ѥޤ<br />򸫤Ĥǥڡ˽񤭴ޤ<br />ONǤ');
define($constpref.'_DIE_NULLBYTE','̥ʸ򸫤ĤǤζλ');
define($constpref.'_DIE_NULLBYTEDSC','ʸλ饯Ǥ "\\0" ϡդ빶Ѥޤ<br />ONǤ');
define($constpref.'_DIE_BADEXT','¹Բǽե륢åץɤˤ붯λ');
define($constpref.'_DIE_BADEXTDSC','ĥҤ.phpʤɡоǼ¹ԲǽȤʤꤨե뤬åץɤ줿˶λޤ<br />B-WikiPukiWikiMod򤪻ȤǡˤPHPեźդϡOFFˤƲ');
define($constpref.'_CONTAMI_ACTION','ѿĤäν');
define($constpref.'_CONTAMI_ACTIONDS','XOOPSΥƥ॰Х񤭤褦Ȥ빶򸫤Ĥν򤷤ޤ<br />ʽͤϡֶλס');
define($constpref.'_ISOCOM_ACTION','ΩȤĤäν');
define($constpref.'_ISOCOM_ACTIONDSC','SQL󥸥к<br />ڥˤʤ*/Τʤ/*򸫤Ĥνޤ<br />̵ˡǸ */ Ĥޤ<br />̵פǤ');
define($constpref.'_UNION_ACTION','UNIONĤäν');
define($constpref.'_UNION_ACTIONDSC','SQL󥸥к<br />SQLUNIONʸ򸡽Фνޤ<br />̵ˡUNION  uni-on Ȥޤ<br />̵פǤ');
define($constpref.'_ID_INTVAL','IDѿζѴ');
define($constpref.'_ID_INTVALDSC','ѿ̾idǽΤ򡢿ȶǧޤmyLinks⥸塼äͭǡXSSʤɤɤޤΥ⥸塼ưɤθȤʤǽޤ');
define($constpref.'_FILE_DOTDOT','DirectoryTraversalζػ');
define($constpref.'_FILE_DOTDOTDSC','DirectoryTraversalߤƤȽǤ줿ꥯʸ󤫤顢".." Ȥѥޤ');

define($constpref.'_BF_COUNT','Brute Forceк');
define($constpref.'_BF_COUNTDSC','ѥйޤ10ʬ桢ǻꤷʾ塢˼ԤȡIPݤޤ');

define($constpref.'_DOS_SKIPMODS','DoSƻоݤ鳰⥸塼');
define($constpref.'_DOS_SKIPMODSDSC','⥸塼dirname|ǶڤäϤƤåȷϥ⥸塼ʤɤͭǤ');

define($constpref.'_DOS_EXPIRE','DoSδƻ ()');
define($constpref.'_DOS_EXPIREDSC','DoS䰭դ륯顼Υ٤ɤδƻñ̻');

define($constpref.'_DOS_F5COUNT','F5åȸʤ');
define($constpref.'_DOS_F5COUNTDSC','DoSɸ<br />ꤷƻˡβʾ塢ƱURIؤΥä顢⤵줿ȸʤޤ');
define($constpref.'_DOS_F5ACTION','F5åؤн');

define($constpref.'_DOS_CRCOUNT','դ륯顼ȸʤ');
define($constpref.'_DOS_CRCOUNTDSC','դ륯顼ʥᥢɼܥåˤؤк<br />ꤷƻˡβʾ塢򤵤ä顢դ륯顼ȸʤޤ');
define($constpref.'_DOS_CRACTION','դ륯顼ؤн');

define($constpref.'_DOS_CRSAFE','ݤʤ User-Agent');
define($constpref.'_DOS_CRSAFEDSC','̵ǥĤ륨̾perlɽǵҤޤ<br />) /(msnbot|Googlebot|Yahoo! Slurp)/i');

define($constpref.'_OPT_NONE','ʤ (Τ߼)');
define($constpref.'_OPT_SAN','̵');
define($constpref.'_OPT_EXIT','λ');
define($constpref.'_OPT_BIP','IPϿ(̵)');
define($constpref.'_OPT_BIPTIME0','IPϿ()');

define($constpref.'_DOSOPT_NONE','ʤ (Τ߼)');
define($constpref.'_DOSOPT_SLEEP','Sleep(侩)');
define($constpref.'_DOSOPT_EXIT','exit');
define($constpref.'_DOSOPT_BIP','IPꥹȤ˺ܤ(̵)');
define($constpref.'_DOSOPT_BIPTIME0','IPꥹȤ˺ܤ()');
define($constpref.'_DOSOPT_HTA','.htaccessDENYϿ(Ū)');

define($constpref.'_BIP_EXCEPT','IPϿݸ롼');
define($constpref.'_BIP_EXCEPTDSC','ǻꤵ줿桼ΥϡƤޤäƤ⡢IPȤϿޤ󡣤Υ桼󤷤ƤʤỌ̇̄ޤΤǡղ');

define($constpref.'_DISABLES','ʵǽ̵');

define($constpref.'_BIGUMBRELLA','礭ʻanti-XSSͭˤ');
define($constpref.'_BIGUMBRELLADSC','ͭˤСʤ¿ΥѥXSSȼ򥭥󥻥뤹뤳ȤǤǤ礦100%ǤϤޤ');

define($constpref.'_SPAMURI4U','SPAMк:̥桼˵URL');
define($constpref.'_SPAMURI4UDSC','԰ʳΰ̥桼ƤˡοʾURLäSPAMȸʤޤ0ʤ̵µĤǤ');
define($constpref.'_SPAMURI4G','SPAMк:Ȥ˵URL');
define($constpref.'_SPAMURI4GDSC','ȤƤˡοʾURLäSPAMȸʤޤ0ʤ̵µĤǤ');


}

?>

==> protector-3.2.zip: xoops_trust_path/modules/protector/language/japanese/modinfo.php <==
<?php

if( defined( 'FOR_XOOPS_LANG_CHECKER' ) ) $mydirname = 'protector' ;
$constpref = '_MI_' . strtoupper( $mydirname ) ;

if( defined( 'FOR_XOOPS_LANG_CHECKER' ) || ! defined( $constpref.'_LOADED' ) ) {

define( $constpref.'_LOADED' , 1 ) ;

// The name of this module
define($constpref."_NAME","Xoops Protector");

// A brief description of this module
define($constpref."_DESC","դ빶⤫XOOPS뤿Υ⥸塼<br />DoS,SQL Injection,ѿȤäɤޤ");

// Menu
define($constpref."_ADMININDEX","Protect Center");
define($constpref."_ADVISORY","ƥ");
define($constpref."_PREFIXMANAGER","PREFIX ޥ͡");
define($constpref.'_ADMENU_MYBLOCKSADMIN','') ;

// Configs
define($constpref.'_GLOBAL_DISBL','ưΰŪ');
define($constpref.'_GLOBAL_DISBLDSC','ɸưŪ̵ޤ<br />꤬褵줿̵뤳Ȥ˺ʤ');

define($constpref.'_DEFAULT_LANG','ȤΥǥեȸ');
define($constpref.'_DEFAULT_LANGDSC','commonζλåɽꤷޤ');

define($constpref.'_RELIABLE_IPS','ѤǤIP');
define($constpref.'_RELIABLE_IPSDSC','DoSι⸡ΤԤʤIPɥ쥹| ǶڤäƵҤޤ^Ƭ$ɽޤ');

define($constpref.'_LOG_LEVEL','٥');
define($constpref.'_LOG_LEVELDSC','');

define($constpref.'_BANIP_TIME0','IPݤδ()');

define($constpref.'_LOGLEVEL0','ϰڤʤ');
define($constpref.'_LOGLEVEL15','ι⤤Τ');
define($constpref.'_LOGLEVEL63','㤤Τϥʤ');
define($constpref.'_LOGLEVEL255','Υ󥰤ͭȤ');

define($constpref.'_HIJACK_TOPBIT','å³ݸӥå');
define($constpref.'_HIJACK_TOPBITDSC','åϥåк<br />̾32(bit)ǡӥåȤݸޤ<br />ProxyѤʤɤǡIPɥ쥹ѤˤϡưʤĹΥӥåȿꤷޤ<br />㤨С192.168.0.0192.168.0.255ưǽ硢ˤ24(bit)Ȼꤷޤ');
define($constpref.'_HIJACK_DENYGP','IPưػߤ륰롼');
define($constpref.'_HIJACK_DENYGPDSC','åϥåк<br />å˰ۤʤIPɥ쥹ϰϡʾˤƥӥåȿˤΥػߤ륰롼פꤷޤ<br />ʴԤˤĤONˤ뤳Ȥ򤪴ᤷޤ');
define($constpref.'_SAN_NULLBYTE','̥ʸ򥹥ڡѹ');
define($constpref.'_SAN_NULLBYTEDSC','ʸλ饯Ǥ "\\0" ϡդ빶Ѥޤ<br />򸫤Ĥǥڡ˽񤭴ޤ<br />ONǤ');
define($constpref.'_DIE_NULLBYTE','̥ʸ򸫤ĤǤζλ');
define($constpref.'_DIE_NULLBYTEDSC','ʸλ饯Ǥ "\\0" ϡդ빶Ѥޤ<br />ONǤ');
define($constpref.'_DIE_BADEXT','¹Բǽե륢åץɤˤ붯λ');
define($constpref.'_DIE_BADEXTDSC','ĥҤ.phpʤɡоǼ¹ԲǽȤʤꤨե뤬åץɤ줿˶λޤ<br />B-WikiPukiWikiMod򤪻ȤǡˤPHPեźդϡOFFˤƲ');
define($constpref.'_CONTAMI_ACTION','ѿĤäν');
define($constpref.'_CONTAMI_ACTIONDS','XOOPSΥƥ॰Х񤭤褦Ȥ빶򸫤Ĥν򤷤ޤ<br />ʽͤϡֶλס');
define($constpref.'_ISOCOM_ACTION','ΩȤĤäν');
define($constpref.'_ISOCOM_ACTIONDSC','SQL󥸥к<br />ڥˤʤ*/Τʤ/*򸫤Ĥνޤ<br />̵ˡǸ */ Ĥޤ<br />̵פǤ');
define($constpref.'_UNION_ACTION','UNIONĤäν');
define($constpref.'_UNION_ACTIONDSC','SQL󥸥к<br />SQLUNIONʸ򸡽Фνޤ<br />̵ˡUNION  uni-on Ȥޤ<br />̵פǤ');
define($constpref.'_ID_INTVAL','IDѿζѴ');
define($constpref.'_ID_INTVALDSC','ѿ̾idǽΤ򡢿ȶǧޤmyLinks⥸塼äͭǡXSSʤɤɤޤΥ⥸塼ưɤθȤʤǽޤ');
define($constpref.'_FILE_DOTDOT','DirectoryTraversalζػ');
define($constpref.'_FILE_DOTDOTDSC','DirectoryTraversalߤƤȽǤ줿ꥯʸ󤫤顢".." Ȥѥޤ');

define($constpref.'_BF_COUNT','Brute Forceк');
define($constpref.'_BF_COUNTDSC','ѥйޤ10ʬ桢ǻꤷʾ塢˼ԤȡIPݤޤ');

define($constpref.'_BWLIMIT_COUNT','Фؤβк');
define($constpref.'_BWLIMIT_COUNTDSC','ƻ˵Ĥ祢ꤷޤCPUӰʤɤϼʴĶǡФؤβ٤򤱤ˤΤ߻ꤷƤΤ10̤οͤξ̵뤵ޤ');

define($constpref.'_DOS_SKIPMODS','DoSƻоݤ鳰⥸塼');
define($constpref.'_DOS_SKIPMODSDSC','⥸塼dirname|ǶڤäϤƤåȷϥ⥸塼ʤɤͭǤ');

define($constpref.'_DOS_EXPIRE','DoSδƻ ()');
define($constpref.'_DOS_EXPIREDSC','DoS䰭դ륯顼Υ٤ɤδƻñ̻');

define($constpref.'_DOS_F5COUNT','F5åȸʤ');
define($constpref.'_DOS_F5COUNTDSC','DoSɸ<br />ꤷƻˡβʾ塢ƱURIؤΥä顢⤵줿ȸʤޤ');
define($constpref.'_DOS_F5ACTION','F5åؤн');

define($constpref.'_DOS_CRCOUNT','դ륯顼ȸʤ');
define($constpref.'_DOS_CRCOUNTDSC','դ륯顼ʥᥢɼܥåˤؤк<br />ꤷƻˡβʾ塢򤵤ä顢դ륯顼ȸʤޤ');
define($constpref.'_DOS_CRACTION','դ륯顼ؤн');

define($constpref.'_DOS_CRSAFE','ݤʤ User-Agent');
define($constpref.'_DOS_CRSAFEDSC','̵ǥĤ륨̾perlɽǵҤޤ<br />) /(msnbot|Googlebot|Yahoo! Slurp)/i');

define($constpref.'_OPT_NONE','ʤ (Τ߼)');
define($constpref.'_OPT_SAN','̵');
define($constpref.'_OPT_EXIT','λ');
define($constpref.'_OPT_BIP','IPϿ(̵)');
define($constpref.'_OPT_BIPTIME0','IPϿ()');

define($constpref.'_DOSOPT_NONE','ʤ (Τ߼)');
define($constpref.'_DOSOPT_SLEEP','Sleep(侩)');
define($constpref.'_DOSOPT_EXIT','exit');
define($constpref.'_DOSOPT_BIP','IPꥹȤ˺ܤ(̵)');
define($constpref.'_DOSOPT_BIPTIME0','IPꥹȤ˺ܤ()');
define($constpref.'_DOSOPT_HTA','.htaccessDENYϿ(Ū)');

define($constpref.'_BIP_EXCEPT','IPϿݸ롼');
define($constpref.'_BIP_EXCEPTDSC','ǻꤵ줿桼ΥϡƤޤäƤ⡢IPȤϿޤ󡣤Υ桼󤷤ƤʤỌ̇̄ޤΤǡղ');

define($constpref.'_DISABLES','ʵǽ̵');

define($constpref.'_BIGUMBRELLA','礭ʻanti-XSSͭˤ');
define($constpref.'_BIGUMBRELLADSC','ͭˤСʤ¿ΥѥXSSȼ򥭥󥻥뤹뤳ȤǤǤ礦100%ǤϤޤ');

define($constpref.'_SPAMURI4U','SPAMк:̥桼˵URL');
define($constpref.'_SPAMURI4UDSC','԰ʳΰ̥桼ƤˡοʾURLäSPAMȸʤޤ0ʤ̵µĤǤ');
define($constpref.'_SPAMURI4G','SPAMк:Ȥ˵URL');
define($constpref.'_SPAMURI4GDSC','ȤƤˡοʾURLäSPAMȸʤޤ0ʤ̵µĤǤ');


}

?>
